# libgen-search
Automatically downloads books from libgen given the book title.

Uses nltk to compare the similarity between the search term and the book title because libgen sometimes doesn't display books with exactly matching titles first.

You can edit the extensions you want to use in the settings.ini file, as well as what language of books you prefer.

`$ python main.py Algebraic Geometry`

Plan to add ability to search by authors since that's pretty important, like there will be tons of books called the same thing but by different authors. 

